@@ -36,7 +36,7 @@ EnvId = Literal[
     # "animal_shogi",
     "backgammon",
     # "bridge_bidding",
-    # "connect_four",
+    "connect_four",
     "go-9x9",
     "go-19x19",
     "hex",
@@ -200,11 +200,19 @@ class Env(abc.ABC):
         return state.replace(reward=reward, terminated=TRUE)  # type: ignore
 
 
+def available_games() -> Tuple[EnvId, ...]:
+    return get_args(EnvId)
+
+
 def make(env_id: EnvId):
     if env_id == "backgammon":
         from pgx.backgammon import Backgammon
 
         return Backgammon()
+    if env_id == "connect_four":
+        from pgx.connect_four import ConnectFour
+
+        return ConnectFour()
     elif env_id == "go-9x9":
         from pgx.go import Go
 
@@ -230,7 +238,7 @@ def make(env_id: EnvId):
 
         return TicTacToe()
     else:
-        available_envs = "\n".join(get_args(EnvId))
+        available_envs = "\n".join(available_games())
         raise ValueError(
             f"Wrong env_id is passed. Available ids are: \n{available_envs}"
         )
