@@ -1,4 +1,5 @@
 import random
+import jax
 
 from minatar import Environment
 
@@ -18,7 +19,9 @@ state_keys = {
     "terminal",
     "last_action",
 }
-
+_step_det = jax.jit(breakout._step_det)
+_init_det = jax.jit(breakout._init_det)
+observe = jax.jit(breakout.observe)
 
 def test_step_det():
     env = Environment("breakout", sticky_action_prob=0.0)
@@ -33,8 +36,8 @@ def test_step_det():
             a = random.randrange(num_actions)
             r, done = env.act(a)
             s_next = extract_state(env, state_keys)
-            s_next_pgx, _, _ = breakout._step_det(
-                minatar2pgx(s, breakout.MinAtarBreakoutState), a
+            s_next_pgx, _, _ = _step_det(
+                minatar2pgx(s, breakout.State), a
             )
             assert_states(s_next, pgx2minatar(s_next_pgx, state_keys))
 
@@ -43,8 +46,8 @@ def test_step_det():
         a = random.randrange(num_actions)
         r, done = env.act(a)
         s_next = extract_state(env, state_keys)
-        s_next_pgx, _, _ = breakout._step_det(
-            minatar2pgx(s, breakout.MinAtarBreakoutState), a
+        s_next_pgx, _, _ = _step_det(
+            minatar2pgx(s, breakout.State), a
         )
         assert_states(s_next, pgx2minatar(s_next_pgx, state_keys))
 
@@ -56,7 +59,7 @@ def test_init_det():
         env.reset()
         ball_start = 0 if env.env.ball_x == 0 else 1
         s = extract_state(env, state_keys)
-        s_pgx = breakout._init_det(ball_start)
+        s_pgx = _init_det(ball_start)
         assert_states(s, pgx2minatar(s_pgx, state_keys))
 
 
@@ -70,8 +73,8 @@ def test_observe():
         done = False
         while not done:
             s = extract_state(env, state_keys)
-            s_pgx = minatar2pgx(s, breakout.MinAtarBreakoutState)
-            obs_pgx = breakout.observe(s_pgx)
+            s_pgx = minatar2pgx(s, breakout.State)
+            obs_pgx = observe(s_pgx)
             assert jnp.allclose(
                 env.state(),
                 obs_pgx,
@@ -81,8 +84,8 @@ def test_observe():
 
         # check terminal state
         s = extract_state(env, state_keys)
-        s_pgx = minatar2pgx(s, breakout.MinAtarBreakoutState)
-        obs_pgx = breakout.observe(s_pgx)
+        s_pgx = minatar2pgx(s, breakout.State)
+        obs_pgx = observe(s_pgx)
         assert jnp.allclose(
             env.state(),
             obs_pgx,
