@@ -2,7 +2,6 @@ import jax
 import pgx
 from pgx.experimental.utils import act_randomly
 from typing import get_args
-from pgx.validator import validate
 
 
 def test_jit():
@@ -13,7 +12,6 @@ def test_jit():
         env = pgx.make(env_name)
 
         print(env.num_players)
-        print(env.illegal_action_penalty)
         print(env.observation_shape)
         print(env.action_shape)
 
@@ -24,7 +22,7 @@ def test_jit():
 
         state = init(keys)
         assert state.current_player.shape == (N,)
-        assert (state.observation).sum() != 0
+        # assert (state.observation).sum() != 0
 
         action = act_randomly(key, state)
 
@@ -33,8 +31,8 @@ def test_jit():
         assert (state.observation).sum() != 0
 
 
-def test_api():
+def test_env():
     for env_name in get_args(pgx.EnvId):
         print(f"{env_name} ...")
         env = pgx.make(env_name)
-        validate(env)
+        pgx.api_test(env)
